@@ -39,7 +39,7 @@ class Hook(NamespacedResource, MTV):
         self.image = image
         self.playbook = playbook
 
-    def to_dict(self) -> None:
+    def to_dict(self):
         super().to_dict()
         if not self.yaml_file:
             self.res.update({
